@@ -14,11 +14,16 @@ from .LoginExpiredException import LoginExpiredException
 
 class SmartqqClient:
     def handler_wrapper(self, orig_handler):
-        return lambda message: ((orig_handler(message, self.env) if self.passing_env else orig_handler(message)),
-                                self.stopped)[1]
+        return lambda message: (
+            True if self.stopped else
+            ((orig_handler(message, self.env) if self.passing_env else orig_handler(message)), False)[1]
+        )
 
     def raw_handler_wrapper(self, orig_handler):
-        return lambda data: (orig_handler(data), self.stopped)[1]
+        return lambda data: (
+            True if self.stopped else
+            (orig_handler(data), False)[1]
+        )
 
     @staticmethod
     def get_group_name(group_info):
@@ -159,6 +164,7 @@ class SmartqqClient:
         )
         self.env["contact_manager"] = self.contact_manager
         self.env["group_manager"] = self.group_manager
+        self.env["uin"] = self.login_data["uin"]
         if self.login_done_handler is not None:
             self.login_done_handler()
 
